==> rendition-11.15.0.tgz: package/dist_esm5/components/Divider/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Txt from '../Txt';
var Base = styled.hr(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tborder: ", ";\n\theight: ", ";\n"], ["\n\tborder: ",
    ";\n\theight: ", ";\n"])), function (props) {
    return px(props.height || 0.5) + " " + (props.type || 'solid') + " " + (props.color ||
        props.theme.colors.quartenary.main) + "}";
}, function (props) { return px(props.height || 0.5); });
var FlexBase = styled(Base)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tflex: 1 1 0;\n\tmargin: auto;\n"], ["\n\tflex: 1 1 0;\n\tmargin: auto;\n"])));
var Divider = React.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, otherProps = __rest(_a, ["children", "className"]);
    if (!children) {
        return React.createElement(Base, __assign({ className: className }, otherProps, { ref: ref }));
    }
    if (typeof children !== 'string') {
        throw new Error("The child element of the Divider component must be a string, received: " + typeof children);
    }
    return (React.createElement(Flex, { className: className, width: "100%", flexDirection: "row", justifyContent: "center", ref: ref },
        React.createElement(FlexBase, __assign({}, otherProps)),
        React.createElement(Txt.span, { color: "tertiary.main", px: 3 }, children),
        React.createElement(FlexBase, __assign({}, otherProps))));
});
export default asRendition(Divider, [], ['color']);
var templateObject_1, templateObject_2;

==> rendition-11.21.1.tgz: package/dist_esm5/components/Divider/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Txt from '../Txt';
var Base = styled.hr(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tborder: ", ";\n\twidth: 100%;\n\theight: 0;\n"], ["\n\tborder: ",
    ";\n\twidth: 100%;\n\theight: 0;\n"])), function (props) {
    return px(props.height || 0.5) + " " + (props.type || 'solid') + " " + (props.color ||
        props.theme.colors.quartenary.main) + "}";
});
var FlexBase = styled(Base)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tflex: 1 1 0;\n\tmargin: auto;\n"], ["\n\tflex: 1 1 0;\n\tmargin: auto;\n"])));
var Divider = React.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, otherProps = __rest(_a, ["children", "className"]);
    if (!children) {
        return React.createElement(Base, __assign({ className: className }, otherProps, { ref: ref }));
    }
    if (typeof children !== 'string') {
        throw new Error("The child element of the Divider component must be a string, received: " + typeof children);
    }
    return (React.createElement(Flex, { className: className, width: "100%", flexDirection: "row", justifyContent: "center", ref: ref },
        React.createElement(FlexBase, __assign({}, otherProps)),
        React.createElement(Txt.span, { color: "tertiary.main", px: 3 }, children),
        React.createElement(FlexBase, __assign({}, otherProps))));
});
export default asRendition(Divider, [], ['color']);
var templateObject_1, templateObject_2;
